summaryrefslogtreecommitdiffstats
path: root/knewstuff/provider.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit1dcbbe821d337f155c5835aa372db3cadcc31ed8 (patch)
treea0b305d9d9334acfe296542840e8e05fbc63bae9 /knewstuff/provider.h
parent9c49a74a165b8535c28ccbb2fad37334989b2fc7 (diff)
downloadtdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.tar.gz
tdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knewstuff/provider.h')
-rw-r--r--knewstuff/provider.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/knewstuff/provider.h b/knewstuff/provider.h
index 98b5b7def..37e2a8daf 100644
--- a/knewstuff/provider.h
+++ b/knewstuff/provider.h
@@ -176,9 +176,9 @@ class KDE_EXPORT ProviderLoader : public TQObject
/**
* Constructor.
*
* @param tqparentWidget the parent widget
*/
- ProviderLoader( TQWidget *tqparentWidget );
+ ProviderLoader( TQWidget *parentWidget );
/**
* Starts asynchronously loading the list of providers of the
@@ -176,9 +176,9 @@ class KDE_EXPORT ProviderLoader : public TQObject
* Constructor.
*
- * @param tqparentWidget the parent widget
+ * @param parentWidget the parent widget
*/